(function ($, Drupal) {
  Drupal.inputPattern = {
    formatValue: function(el) {
      const separator = el.getAttribute('separator')
      const step = el.getAttribute('step')
      if (separator && step) {
        const removeSeparator= new RegExp(`\\${separator}`, 'g');
        const addSeparator= new RegExp(`\\B(?=(\\d{${step}})+(?!\\d))`, 'g');
        const initialValue= el.value || '';
        const cleanValue = initialValue.replace(removeSeparator, '');
        el.value = !isNaN(cleanValue) && cleanValue !== ''
          ? cleanValue.replace(addSeparator, separator)
          : initialValue;
      }
    },
    getValue: function(el) {
      if (el instanceof jQuery) el = el.get(0);
      if (typeof AutoNumeric !== 'undefined') {
        let el_instance = AutoNumeric.getAutoNumericElement(el);
        if (el_instance) {
          return el_instance.getNumber();
        }
      }
      const separator = el.getAttribute('separator');
      if (separator) {
        const removeSeparator = new RegExp(`\\${separator}`, 'g');
        const initialValue = el.value || '';
        return parseFloat(initialValue.replace(removeSeparator, ''));
      }
      else {
        return el.value || el.getAttribute('value') || ''
      }
    },
    setValue: function(el, new_value) {
      if (el instanceof jQuery) el = el.get(0);
      if (typeof AutoNumeric !== 'undefined') {
        let el_instance = AutoNumeric.getAutoNumericElement(el);
        if (el_instance) {
          el_instance.set(new_value);
          return;
        }
      }
      const separator = el.getAttribute('separator')
      const step = el.getAttribute('step')
      if (separator && step) {
        const removeSeparator= new RegExp(`\\${separator}`, 'g');
        const addSeparator= new RegExp(`\\B(?=(\\d{${step}})+(?!\\d))`, 'g');
        const initialValue= el.value || '';
        const cleanValue = initialValue.replace(removeSeparator, '');
        el.value = !isNaN(cleanValue) && cleanValue !== ''
          ? cleanValue.replace(addSeparator, separator)
          : initialValue;
      }
      else {
        el.value = new_value
      }
    },
  }

})(jQuery, Drupal);
