/**
 * @file
 * Input pattern behaviors.
 */
(function (Drupal, once) {

  'use strict';

  Drupal.behaviors.inputPatternInputPattern = {
    attach (context, settings) {
      once('input-pattern', '.input-pattern', context).forEach((input) => {
        const use_auto_numeric = input.getAttribute('use_auto_numeric') || false;

        if (input.type === 'number') input.type = 'text';

        if (use_auto_numeric) {
          const field_type = input.hasAttribute('field_type') ? input.getAttribute('field_type') : null;
          const scale = input.hasAttribute('scale') ? parseFloat(input.getAttribute('scale')) : null;

          const onInvalidPaste = 'error'
          const allowDecimalPadding = false
          const decimalPlaces = field_type.includes('int') ? 0 : scale || 3
          const maximumValue = input.getAttribute('data-max')
          const minimumValue = input.getAttribute('data-min')
          const showWarnings = false

          let config = {
            modifyValueOnWheel: false,
            onInvalidPaste: onInvalidPaste,
            allowDecimalPadding: allowDecimalPadding,
            decimalPlaces: decimalPlaces,
            showWarnings: showWarnings,
          }

          if (/^\d+(\.\d+)?$/.test(maximumValue)) {
            config.maximumValue = maximumValue
          }
          if (/^\d+(\.\d+)?$/.test(minimumValue)) {
            config.minimumValue = minimumValue
          }

          let language = drupalSettings.auto_numeric.language;
          if (language) {
            let option = AutoNumeric.getPredefinedOptions()[language];
            let newOption = Object.assign({}, option);
            newOption.currencySymbol = '';
            config = { ...config, ...newOption }
            new AutoNumeric(input, config);
          }
        }
        else {
          Drupal.inputPattern.formatValue(input);
          input.addEventListener('input', () => {
            Drupal.inputPattern.formatValue(input);
          });
        }
      });
    }
  };

} (Drupal, once));
